==> bibletime_1.5.1.orig.tar.gz: bibletime-1.5.1/bibletime/frontend/keychooser/cbiblekeychooser.h <==
/********* Read the file LICENSE for license details. *********/

#ifndef CBIBLEKEYCHOOSER_H
#define CBIBLEKEYCHOOSER_H

#include <qwidget.h>
#include "ckeychooser.h"

#include "backend/cswordbiblemoduleinfo.h"

class CKeyChooserWidget;
class CSwordVerseKey;

class CSwordBibleModuleInfo;

class QuickBrowseDialog;


/** This class implements the KeyChooser for bibles and commentaries
 *
 * it inhertits @ref CKeyChooser
 *
 * it uses 3 @ref CKeyChooserWidget 's to represent the bible keys
 *
  * @author The BibleTime team
  */

class CBibleKeyChooser : public CKeyChooser  {
	Q_OBJECT

public:
	/**
	* the constructor
	* you should not need to use this, use @ref CKeyChooser::createInstance instead
	*/
	CBibleKeyChooser(ListCSwordModuleInfo modules, CSwordKey *key=0, QWidget *parent=0, const char *name=0);

public slots:
	/**
	* see @ref CKeyChooser::getKey
	*/
	CSwordKey* const key();
	/**
	* see @ref CKeyChooser::setKey
	*/
	virtual void setKey(CSwordKey *key);
	/**
	* Reimplementation
	*/
	virtual QSize sizeHint();
	/**
	* Sets te module and refreshes the combos
	*/
	virtual void setModules(const ListCSwordModuleInfo& modules, const bool refresh = true);
	/**
	* Reimplementation.
	*/
	void refreshContent();
	/**
	* used to react to changes in the 3 @ref CKeyChooserWidget 's
	* @param index not used
	*/
	void bookChanged(int index);
	/**
	* used to react to changes in the 3 @ref CKeyChooserWidget 's
	* @param index not used
	*/
	void chapterChanged(int index);
	/**
	* used to react to changes in the 3 @ref CKeyChooserWidget 's
	* @param index not used
	*/
	void verseChanged(int index);
	/**
	* see @ref bookPrevRequested
	*/
	void chapterPrevRequested(void);
	/**
	* see @ref bookPrevRequested
	*/
	void chapterNextRequested(void);
	/**
	* see @ref bookPrevRequested
	*/
	void versePrevRequested(void);
	/**
	* see @ref bookPrevRequested
	*/
	void verseNextRequested(void);
	void updateKey(CSwordKey* key);


protected:
	virtual void adjustFont();

private:
	CKeyChooserWidget* w_book;
	CKeyChooserWidget* w_chapter;
	CKeyChooserWidget* w_verse;
	QPtrList<CSwordBibleModuleInfo> m_modules;
	CSwordVerseKey *m_key;

private slots: // Private slots
	/**
	* called when the book combo lost the focus with reason == tab
	* @param the new book
	*/
	void bookFocusOut(int);
	/**
	* called when the chapter combo lost the focus with reason == tab
	* @param the new chapter
	*/
	void chapterFocusOut(int);
	/** called when the verse combo lost the focus
	with reason == tab
	@param the new verse
	*/
	void verseFocusOut(int);
};

#endif

==> bibletime_1.6.2.dfsg.orig.tar.gz: bibletime-1.6.2.dfsg/bibletime/frontend/keychooser/cbiblekeychooser.h <==
/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2006 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/



#ifndef CBIBLEKEYCHOOSER_H
#define CBIBLEKEYCHOOSER_H

#include <qwidget.h>
#include "ckeychooser.h"

#include "backend/cswordbiblemoduleinfo.h"

class CKeyReferenceWidget;
class CSwordVerseKey;

class CSwordBibleModuleInfo;

class QuickBrowseDialog;


/** This class implements the KeyChooser for bibles and commentaries
 *
 * it inhertits @ref CKeyChooser
 *
 * it uses a CKeyReferenceWidget 's to represent the bible keys
 *
  * @author The BibleTime team
  */

class CBibleKeyChooser : public CKeyChooser  {
	Q_OBJECT

public:
	/**
	* the constructor
	* you should not need to use this, use @ref CKeyChooser::createInstance instead
	*/
	CBibleKeyChooser(ListCSwordModuleInfo modules, CSwordKey *key=0, QWidget *parent=0, const char *name=0);

public slots:
	/**
	* see @ref CKeyChooser::getKey
	*/
	CSwordKey* const key();
	/**
	* see @ref CKeyChooser::setKey
	*/
	virtual void setKey(CSwordKey *key);
	/**
	* Sets the module
	*/
	virtual void setModules(const ListCSwordModuleInfo& modules, const bool refresh = true);
	/**
	* used to react to changes
	* @param index not used
	*/
	void refChanged(CSwordVerseKey *key);

	void updateKey(CSwordKey* key);
	void adjustFont();
	void refreshContent();


private:
	CKeyReferenceWidget* w_ref;
	QPtrList<CSwordBibleModuleInfo> m_modules;
	CSwordVerseKey *m_key;
};

#endif
